%define upstream_name Lexical-Var
%define upstream_version 0.009

Name:		perl-%{upstream_name}
Version:	%perl_convert_version %{upstream_version}
Release:	%mkrel 16

Summary:	Static variables without namespace pollution
License:	GPL+ or Artistic
Group:		Development/Perl
Url:		https://metacpan.org/release/%{upstream_name}
Source0:	https://cpan.metacpan.org/modules/by-module/Lexical/%{upstream_name}-%{upstream_version}.tar.gz
Patch1:     Lexical-Var-0.009.patch

BuildRequires:	perl(Lexical::SealRequireHints)
BuildRequires:	perl(Module::Build)
BuildRequires:	perl-devel

%{?perl_default_filter}

%description
This module implements lexical scoping of static variables and
subroutines.  Although it can be used directly, it is mainly intended
to be infrastructure for modules that manage namespaces.

This module influences the meaning of single-part variable names that
appear directly in code, such as "$foo".  Normally, in the absence of any
particular declaration, or under the effect of an "our" declaration, this
would refer to the scalar variable of that name located in the current
package.  A "Lexical::Var" declaration can change this to refer to any
particular scalar, bypassing the package system entirely.  A variable
name that includes an explicit package part, such as "$main::foo", always
refers to the variable in the specified package, and is unaffected by this
module.  A symbolic reference through a string value, such as "${'foo'}",
also looks in the package system, and so is unaffected by this module.

The types of name that can be influenced are scalar ("$foo"), array
("@foo"), hash ("%foo"), subroutine ("&foo"), and glob ("*foo").
A definition for any of these names also affects code that logically
refers to the same entity, even when the name is spelled without its
usual sigil.  For example, any definition of "@foo" affects element
references such as "$foo[0]".  Barewords in filehandle context actually
refer to the glob variable.  Bareword references to subroutines, such as
"foo(123)", only work on Perl 5.11.2 and later; on earlier Perls you
must use the "&" sigil, as in "&foo(123)".

Where a scalar name is defined to refer to a constant (read-only) scalar,
references to the constant through the lexical namespace can participate
in compile-time constant folding.  This can avoid the need to check
configuration values (such as whether debugging is enabled) at runtime.

A name definition supplied by this module takes effect from the end
of the definition statement up to the end of the immediately enclosing
block, except where it is shadowed within a nested block.  This is the
same lexical scoping that the "my", "our", and "state" keywords supply.
Definitions from Lexical::Var and from "my"/"our"/"state" can shadow
each other.  These lexical definitions propagate into string "eval"s,
on Perl versions that support it (5.9.3 and later).

This module only manages variables of static duration (the kind of
duration that "our" and "state" variables have).  To get a fresh variable
for each invocation of a function, use "my".

%prep
%setup -q -n %{upstream_name}-%{upstream_version}
# See https://rt.cpan.org/Public/Bug/Display.html?id=101058
%autopatch -p1

%build
%__perl Build.PL installdirs=vendor

./Build

%check
./Build test

%install
./Build install destdir=%{buildroot}

%files
%doc Changes META.json META.yml MYMETA.yml README SIGNATURE
%{_mandir}/man3/*
%{perl_vendorarch}/*


%changelog
* Sat Jul 18 2020 tv <tv> 0.9.0-16.mga8
+ Revision: 1606984
- rebuild for perl-5.32 (binary package w/o a dep on libperl.so

* Wed Feb 12 2020 umeabot <umeabot> 0.9.0-15.mga8
+ Revision: 1508361
- Mageia 8 Mass Rebuild

* Fri Sep 21 2018 umeabot <umeabot> 0.9.0-14.mga7
+ Revision: 1293316
- Mageia 7 Mass Rebuild

* Wed Aug 08 2018 pterjan <pterjan> 0.9.0-13.mga7
+ Revision: 1249791
- Rebuild for perl 5.28

* Tue Oct 03 2017 tv <tv> 0.9.0-12.mga7
+ Revision: 1165126
- rebuild with fixed rpm for missing autodeps

* Mon Sep 25 2017 tv <tv> 0.9.0-11.mga7
+ Revision: 1159103
- rebuild with perl-5.26.x

* Sun Jun 19 2016 pterjan <pterjan> 0.9.0-10.mga6
+ Revision: 1029135
- Rebuild for perl 5.22.2

* Fri Feb 12 2016 umeabot <umeabot> 0.9.0-9.mga6
+ Revision: 957615
- Mageia 6 Mass Rebuild

* Fri Jun 26 2015 tv <tv> 0.9.0-8.mga6
+ Revision: 844946
- rebuild for soname-ifed perl

* Wed Jun 24 2015 shlomif <shlomif> 0.9.0-7.mga6
+ Revision: 841953
- Rebuild for the new perl-5.22.0

* Wed Oct 15 2014 umeabot <umeabot> 0.9.0-6.mga5
+ Revision: 745305
- Second Mageia 5 Mass Rebuild

* Tue Sep 30 2014 tv <tv> 0.9.0-5.mga5
+ Revision: 733107
- add exclude

* Tue Sep 16 2014 umeabot <umeabot> 0.9.0-4.mga5
+ Revision: 685201
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 jquelin <jquelin> 0.9.0-3.mga5
+ Revision: 632296
- perl 5.20.0 rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.9.0-2.mga4
+ Revision: 533202
- Mageia 4 Mass Rebuild

* Mon Aug 26 2013 sander85 <sander85> 0.9.0-1.mga4
+ Revision: 471988
- update to 0.009

* Mon Aug 19 2013 sander85 <sander85> 0.8.0-1.mga4
+ Revision: 467881
- imported package perl-Lexical-Var

